//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenArgsValidationException](index.md)/[args](args.md)

# args

[common]\
val [args](args.md): [FuroChanceShantenArgs](../-furo-chance-shanten-args/index.md)
